import React from 'react'
import { th } from '@pubsweet/ui'
import styled from 'styled-components'

const TR = ({ name, email, affiliation }) => (
  <Row>
    <td>{name}</td>
    <td>{email}</td>
    <td>{affiliation}</td>
  </Row>
)

const Authors = ({ authors }) => (
  <Table>
    <thead>
      <tr>
        <td>Full Name</td>
        <td>Email</td>
        <td>Affiliation</td>
      </tr>
    </thead>
    <tbody>
      {authors.map(
        ({ firstName = '', lastName = '', email = '', affiliation = '' }) => (
          <TR
            affiliation={affiliation}
            email={email}
            key={email}
            name={`${firstName} ${lastName}`}
          />
        ),
      )}
    </tbody>
  </Table>
)

export default Authors

// #region styled-components
const Row = styled.tr`
  border-bottom: ${th('borderDefault')};
  color: ${th('colorPrimary')};
  font-family: ${th('fontReading')};
  font-size: ${th('fontSizeBaseSmall')};
  height: 40px;
  text-align: left;
  &:hover {
    background-color: ${th('backgroundColorReverse')};
  }
`

const Table = styled.table`
  border-spacing: 0;
  border-collapse: collapse;
  width: 100%;

  & thead tr {
    border-bottom: ${th('borderDefault')};
    color: ${th('colorPrimary')};
    font-family: ${th('fontReading')};
    font-size: ${th('fontSizeBaseSmall')};
    font-weight: bold;
    height: 40px;
    text-align: left;
  }
`
// #endregion
