import React from 'react'
import styled from 'styled-components'
import { th, Icon } from '@pubsweet/ui'
import { compose, withState, withHandlers } from 'recompose'

const Expandable = ({ expanded, label, children, toggle }) => (
  <Root expanded={expanded}>
    <Header onClick={toggle}>
      <Chevron expanded={expanded}>
        <Icon primary size={3}>
          chevron_up
        </Icon>
      </Chevron>
      <SectionLabel>{label}</SectionLabel>
    </Header>
    {expanded && <ChildrenContainer>{children}</ChildrenContainer>}
  </Root>
)

export default compose(
  withState('expanded', 'setExpanded', ({ startExpanded }) => startExpanded),
  withHandlers({
    toggle: ({ setExpanded }) => () => {
      setExpanded(e => !e)
    },
  }),
)(Expandable)

// #region styled-components
const Chevron = styled.div`
  align-items: center;
  height: calc(${th('subGridUnit')} * 5);
  display: flex;
  justify-content: center;
  transform: ${({ expanded }) => `rotateZ(${expanded ? 0 : 180}deg)`};
  transition: transform 0.2s;
  width: calc(${th('subGridUnit')} * 5);
`

const SectionLabel = styled.span`
  color: ${th('colorPrimary')};
  font-family: ${th('fontHeading')};
  font-size: ${th('fontSizeBase')};
  text-transform: uppercase;
`

const ChildrenContainer = styled.div`
  cursor: default;
  padding: calc(${th('subGridUnit')} * 3);
  padding-top: 0;
`

const Header = styled.div`
  align-items: center;
  border-bottom: ${th('borderDefault')};
  margin-bottom: calc(${th('subGridUnit')} * 3);
  cursor: pointer;
  display: flex;
  justify-content: flex-start;
`

const Root = styled.div`
  cursor: pointer;
  display: flex;
  flex-direction: column;
  transition: all 0.3s;
`
// #endregion
