import React from 'react'
import { isEmpty } from 'lodash'
import { th } from '@pubsweet/ui'
import styled from 'styled-components'

import { Authors, Expandable, Files } from './'

const ManuscriptDetails = ({
  previewFile,
  downloadFile,
  collection: { authors = [] },
  fragment: { conflicts = {}, files = {}, metadata: { abstract = '' } },
}) => (
  <Root>
    <Expandable label="Details" startExpanded>
      {!!abstract && (
        <Expandable label="abstract" startExpanded>
          <Text dangerouslySetInnerHTML={{ __html: abstract }} />
        </Expandable>
      )}
      {conflicts.hasConflicts === 'yes' && (
        <Expandable label="Conflict of interest">
          <Text>{conflicts.message}</Text>
        </Expandable>
      )}
      {!!authors.length && (
        <Expandable label="authors">
          <Authors authors={authors} />
        </Expandable>
      )}
      {!isEmpty(files) && (
        <Expandable label="files">
          <Files
            downloadFile={downloadFile}
            files={files}
            previewFile={previewFile}
          />
        </Expandable>
      )}
    </Expandable>
  </Root>
)

export default ManuscriptDetails

// #region styled-components
const Text = styled.span`
  color: ${th('colorPrimary')};
  font-family: ${th('fontReading')};
  font-size: ${th('fontSizeBaseSmall')};
`

const Root = styled.div`
  background-color: ${th('colorBackground')};
  border: ${th('borderDefault')};
  margin-top: calc(${th('subGridUnit')} * 2);
  transition: height 0.3s;
`
// #endregion
